@@ -85,9 +85,9 @@ def bytes_to_list_of_integers(data: bytes, fmt: BinIntFormat) -> List[int]:
 		return bytes_to_int32_list(data)
 	elif fmt == BinIntFormat.Integer32_4bytes_swapped:
 		return bytes_to_int32_list(data, True)
-	elif fmt == BinIntFormat.Integer16_4bytes:
+	elif fmt == BinIntFormat.Integer16_2bytes:
 		return bytes_to_int16_list(data)
-	elif fmt == BinIntFormat.Integer16_4bytes_swapped:
+	elif fmt == BinIntFormat.Integer16_2bytes_swapped:
 		return bytes_to_int16_list(data, True)
 
 
@@ -171,6 +171,8 @@ number_nan_lookup = frozenset(['Nan', 'NAN', 'nan', 'NaN', 'NAV', 'NaV', 'NCAP',
 number_max_lookup = frozenset(['OFL', 'ofl', 'Ofl'])
 number_min_lookup = frozenset(['UFL', 'ufl', 'Ufl'])
 int_neg_inf = -(sys.maxsize - 1)
+enum_spec_prefixes = {'_minus': '-', '_plus': '+', '_': ''}
+enum_spec_strings = {'_dash_': '-', '_dot_': '.'}
 
 
 def str_to_int(string: str) -> int:
@@ -225,7 +227,7 @@ def str_special_values_to_int(string: str) -> int:
 		# noinspection PyTypeChecker
 		return int_neg_inf / 100
 	if string == 'ULEU':
-		return sys.maxsize / 10
+		return int(sys.maxsize / 10)
 	if string == 'ULEL':
 		# noinspection PyTypeChecker
 		return int_neg_inf / 10
@@ -357,11 +359,23 @@ def value_to_str(x: int or bool or float or str or Enum) -> str:
 	elif isinstance(x, str):
 		return x
 	elif isinstance(x, Enum):
-		return x.name.lstrip('_')
+		return enum_value_to_scpi_string(x.name)
 	else:
 		raise Exception(f"value_to_str: unsupported variable type '{type(x)}', value '{x}'. Supported types: int, bool, float, str, enum.")
 
 
+def enum_value_to_scpi_string(enum_value: str) -> str:
+	"""Conversion EnumValue -> SCPI_String
+	Unescapes all the special characters that can not be contained in the enum member definition, but can be sent to the instrument as enum string.
+	Use this to send the scpi enum value to the instrument."""
+	for key in enum_spec_prefixes:
+		if enum_value.startswith(key):
+			enum_value = enum_spec_prefixes[key] + enum_value[len(key):]
+	for key in enum_spec_strings:
+		enum_value = enum_value.replace(key, enum_spec_strings[key])
+	return enum_value
+
+
 def value_to_quoted_str(x: int or bool or float or str or Enum) -> str:
 	"""Converts scalar value to string enclosed by single quotes.
 	Supported element types:
@@ -414,23 +428,18 @@ def str_to_str_list(string: str) -> List[str]:
 	return result
 
 
-def find_in_enum_members(item, enum_members: list):
+def _find_in_enum_members(item: str, enum_members: List[str]) -> int:
 	"""Matches a string in the provided list of member strings.
 	The item must be not fully matched.
-	Rules:
-	- If the member string starts with underscore, it is cut out before the matching continues.
-	- The item is matched if a member string starts with the item (item is a prefix of the member)."""
-	found = None
+	The item is matched if a member string starts with the item (the item is a prefix of the member).
+	Returns found index in the enum_members list"""
+	ix = -1
+	i = 0
 	for x in enum_members:
 		if x.startswith(item):
-			found = x
-			break
-		if x.startswith('_'):
-			# Trim underscore if exists, this is used to escape the first Enum character being a number - not accepted by Python or C#
-			if x.strip('_').startswith(item):
-				found = x
-				break
-	return found
+			return i
+		i += 1
+	return ix
 
 
 def str_to_scalar_enum_helper(string: str, enum_type: Enum, enum_members=None) -> Enum:
@@ -441,9 +450,19 @@ def str_to_scalar_enum_helper(string: str, enum_type: Enum, enum_members=None) -
 	if not enum_members:
 		# noinspection PyTypeChecker
 		enum_members = [x.name for x in enum_type]
-	found = find_in_enum_members(value, enum_members)
-	if found:
-		return enum_type[found]
+
+	# search in the enum member and return the index of the matched item
+	ix = _find_in_enum_members(value, enum_members)
+	if ix >= 0:
+		return enum_type[enum_members[ix]]
+
+	# If the result is -1 (not found), try to replace the special values and search again
+	# This is done to improve the performance, since most of the enums have no special values
+	enum_members_conv = [enum_value_to_scpi_string(x) for x in enum_members]
+	ix = _find_in_enum_members(value, enum_members_conv)
+	if ix >= 0:
+		return enum_type[enum_members[ix]]
+
 	# If not found, search in the special integer numbers:
 	spec_value = str_special_values_to_int(value)
 	if not spec_value:
