@@ -17,18 +17,32 @@ class Core(object):
 		- Command parameters string composer for single arguments...
 		- Link handlers adding / changing / deleting
 
+		1.7.1 (build 36) 08.10.2020
+			- Fixed Python 3.8.5+ warnings
+
+		1.7.0 (build 34) 30.09.2020
+			- Added option to set the termination characters for reading and writing. Until now, it was fixed to '\n' (Linefeed)
+			- Replaced 'import visa' with 'import pyvisa' to remove Python 3.8 pyvisa warnings
+
 		Version History:
+		1.6.0 (build 33) 17.09.2020
+			- Added special characters encoding/decoding in enums
+
+		1.4.0 (build 32) 17.09.2020
+			- Added recognition of RsVisa library location for linux when using options string 'SelectVisa=rs'
+			- Fixed bug in reading binary data 16 bit
+
 		1.3.0 (build 31) 04.09.2020
-		- added DRIVERSETUP_QUERYOPT to the driver's option string
-		- *OPT? is no longer performed at the init, but only at the first access to options string.
-			In addition, the *OPT? query is executed with 1000 ms timeout, and the errors are suppressed
+			- added DRIVERSETUP_QUERYOPT to the driver's option string
+			- *OPT? is no longer performed at the init, but only at the first access to options string.
+				In addition, the *OPT? query is executed with 1000 ms timeout, and the errors are suppressed
 
 		1.2.0 (build 30), 03.08.2020
-		- Fixed NRP-Z session parameters: vxi_capable = False, io_segment_size = 1000000
+			- Fixed NRP-Z session parameters: vxi_capable = False, io_segment_size = 1000000
 
 		1.1.0 (build 29), 20.06.2020
-		- Added RepeatedCapability and base class CommandsGroup
-		- Fixed simulation mode switching
+			- Added RepeatedCapability and base class CommandsGroup
+			- Fixed simulation mode switching
 
 		0.9.3 (build 25), 23.04.2020 - Fixed composition of optional arguments in ArgSingleList and ArgSingle
 		0.9.2 (build 24), 13.11.2019 - Added recognition of special values for enum return strings
@@ -49,7 +63,7 @@ class Core(object):
 		"""Initializes new driver session. For cleaner code, use the class methods: \n
 		- Core.from_existing_session() - initializes a new Core with an existing pyvisa session."""
 
-		self.core_version = '1.2.0'
+		self.core_version = '1.7.1'
 		self.simulating = False
 		self.supported_idn_patterns = []
 		self.supported_instr_models = []
