@@ -192,7 +192,7 @@ class Instrument(object):
 		assert self._idn_string, f'*IDN? was not assigned yet.'
 		for x in patterns:
 			matches = re.search(x, self.idn_string, re.IGNORECASE)
-			if matches is True:
+			if matches:
 				break
 		if not matches:
 			message = f"Instrument is not supported.\n*IDN? string: '{self.idn_string}'"
@@ -334,9 +334,6 @@ class Instrument(object):
 		self.start_send_read_event(query, False)
 		response = self._session.query_str(query)
 		self.end_send_read_event()
-
-		if response.endswith('\n'):
-			response = response.strip()
 		self.check_status()
 		return response
 
@@ -349,8 +346,6 @@ class Instrument(object):
 		self.start_send_read_event(query, True)
 		response = self._session.query_str_with_opc(query, timeout)
 		self.end_send_read_event()
-		if response.endswith('\n'):
-			response = response.strip()
 		self._session.query_and_clear_esr()
 		self.check_status()
 		return response
