@@ -56,7 +56,8 @@ class InstrumentSettings(object):
 		self.bin_int_numbers_format = bin_int_numbers_format
 		self.opc_query_after_write = opc_query_after_write
 
-		self.assure_write_with_lf = False
+		self.assure_write_with_tc = False
+		self.term_char = '\n'
 		self.add_term_char_to_write_bin_block = False
 
 		self.stb_in_error_check = True
@@ -97,9 +98,17 @@ class InstrumentSettings(object):
 		if value is not None:
 			self.add_term_char_to_write_bin_block = Conv.str_to_bool(value)
 
+		# Obsolete, use the DRIVERSETUP_ASSUREWRITEWITHTERMCHAR
 		value = settings.get('DRIVERSETUP_ASSUREWRITEWITHLF')
 		if value is not None:
-			self.assure_write_with_lf = Conv.str_to_bool(value)
+			self.assure_write_with_tc = Conv.str_to_bool(value)
+		value = settings.get('DRIVERSETUP_ASSUREWRITEWITHTERMCHAR')
+		if value is not None:
+			self.assure_write_with_tc = Conv.str_to_bool(value)
+
+		value = settings.get('DRIVERSETUP_TERMINATIONCHARACTER')
+		if value is not None:
+			self.term_char = value
 
 		value = settings.get('DRIVERSETUP_IOSEGMENTSIZE')
 		if value is not None:
