@@ -1,10 +1,11 @@
 import time
 from enum import Enum, Flag
 from typing import Tuple, Callable, AnyStr
+import os.path
 import re
 
 # noinspection PyPackageRequirements
-import visa
+import pyvisa
 
 from .VisaPluginSocketIo import ResourceManager, SocketIo
 from . import InstrumentSettings, InstrumentErrors, Conversions as Conv
@@ -81,7 +82,7 @@ class VisaSession(object):
 
 		if self.reusing_session:
 			# Reuse the session
-			assert isinstance(direct_session, visa.Resource) or isinstance(direct_session, SocketIo), f"Direct_session must be a VISA resource object. Actual type: '{type(direct_session)}', value: '{direct_session}'"
+			assert isinstance(direct_session, pyvisa.Resource) or isinstance(direct_session, SocketIo), f"Direct_session must be a VISA resource object. Actual type: '{type(direct_session)}', value: '{direct_session}'"
 			self._session = direct_session
 			self._resource_name = self._session.resource_name
 		else:
@@ -95,8 +96,8 @@ class VisaSession(object):
 
 			try:
 				self._session = self._rm.open_resource(pure_resource_name)
-			except visa.VisaIOError as e:
-				if e.error_code != visa.constants.StatusCode.error_resource_not_found:
+			except pyvisa.VisaIOError as e:
+				if e.error_code != pyvisa.constants.StatusCode.error_resource_not_found:
 					raise e
 				message = e.description
 				message += f"\nLibrary: {self._rm.visalib}\nManufacturer: {self.manufacturer}\nResource Name: '{resource_name}'"
@@ -105,39 +106,41 @@ class VisaSession(object):
 			self._resource_name = resource_name
 
 		self._interface_type = SessionKind.unsupported
-		if self._session.interface_type == visa.constants.InterfaceType.gpib or self._session.interface_type == visa.constants.InterfaceType.gpib:
+		if self._session.interface_type == pyvisa.constants.InterfaceType.gpib or self._session.interface_type == pyvisa.constants.InterfaceType.gpib:
 			self._interface_type = SessionKind.gpib
 
-		elif self._session.interface_type == visa.constants.InterfaceType.rsnrp:
+		elif self._session.interface_type == pyvisa.constants.InterfaceType.rsnrp:
 			self._interface_type = SessionKind.rs_nrp
 
-		elif self._session.interface_type == visa.constants.InterfaceType.asrl:
+		elif self._session.interface_type == pyvisa.constants.InterfaceType.asrl:
 			self._interface_type = SessionKind.serial
 
-		elif self._session.interface_type == visa.constants.InterfaceType.usb:
+		elif self._session.interface_type == pyvisa.constants.InterfaceType.usb:
 			# Check whether it is not the NRP-Z
-			intf_type = self._session.get_visa_attribute(visa.constants.VI_ATTR_INTF_TYPE)
-			if intf_type == visa.constants.InterfaceType.rsnrp:
+			intf_type = self._session.get_visa_attribute(pyvisa.constants.VI_ATTR_INTF_TYPE)
+			if intf_type == pyvisa.constants.InterfaceType.rsnrp:
 				self._interface_type = SessionKind.rs_nrp
 
-		elif self._session.interface_type == visa.constants.InterfaceType.tcpip:
+		elif self._session.interface_type == pyvisa.constants.InterfaceType.tcpip:
 			self._interface_type = SessionKind.vxi11
 			if self._session.resource_class == 'SOCKET':
 				self._interface_type = SessionKind.socket
 
 		# Specifics for different interfaces
-		self._assure_write_with_lf = settings.assure_write_with_lf
+		self._assure_write_with_tc = settings.assure_write_with_tc
+		self._term_char = settings.term_char
+		self._term_char_bin = self._term_char.encode('utf-8')
 		self._session.write_termination = ''
 		self.vxi_capable = True
 
 		if self._interface_type == SessionKind.serial:
-			self._session.read_termination = '\n'
+			self._session.read_termination = self._term_char
 			self.vxi_capable = False
-			self._assure_write_with_lf = True
+			self._assure_write_with_tc = True
 		elif self._interface_type == SessionKind.socket:
-			self._session.read_termination = '\n'
+			self._session.read_termination = self._term_char
 			self.vxi_capable = False
-			self._assure_write_with_lf = True
+			self._assure_write_with_tc = True
 		else:
 			self._session.read_termination = ''
 
@@ -193,33 +196,41 @@ class VisaSession(object):
 		return resource_name, visa_select
 
 	@classmethod
-	def get_resource_manager(cls, visa_select: str) -> visa.ResourceManager:
+	def get_resource_manager(cls, visa_select: str) -> pyvisa.ResourceManager:
 		"""Returns resource manager for the desired VISA implementation"""
 		operating_system = platform.system().lower()
 		bittness = struct.calcsize("P") * 8
 		if visa_select is None or visa_select in ['@default', '@standard', 'default', 'standard', 'defaultvisa', 'standardvisa', '@defaultvisa', '@standardvisa']:
-			return visa.ResourceManager()
+			return pyvisa.ResourceManager()
 		if visa_select.lower() in ['@ni', 'ni', 'visa-ni', 'nivisa', 'ni-visa', 'nationalinstruments', 'nationalinstrumentsvisa']:
-			return visa.ResourceManager('@ni')
+			return pyvisa.ResourceManager('@ni')
 		if visa_select.lower() in ['@py', 'pyvisa', 'visa-py', 'pyvisa-py']:
-			return visa.ResourceManager('@py')
+			return pyvisa.ResourceManager('@py')
 		if 'rohde&schwarz' in visa_select.lower() or 'rohdeschwarz' in visa_select.lower() or visa_select.lower() == 'rsvisa' or visa_select.lower() == 'rs' or visa_select.lower() == 'r&s':
 			if operating_system == 'windows':
 				if bittness == 32:
 					visa_select = r'c:\Windows\SysWOW64\RsVisa32.dll'
 				else:
 					visa_select = r'c:\Windows\system32\RsVisa32.dll'
-				return visa.ResourceManager(visa_select)
+				return pyvisa.ResourceManager(visa_select)
+			elif operating_system == 'linux':
+				# The default install location may be different
+				# for debian/red hat/opensuse derived distributions
+				check_visa = [f'/usr/lib{bittness}/librsvisa.so', r'/usr/lib/librsvisa.so']
+				for check in check_visa:
+					if os.path.isfile(check):
+						return pyvisa.ResourceManager(check)
+
 		if visa_select.lower() in ['socketio', 'socket', 'none']:
 			return ResourceManager()
-		return visa.ResourceManager(visa_select)
+		return pyvisa.ResourceManager(visa_select)
 
 	def _get_visa_manufacturer(self) -> str:
 		"""Returns manufacturer of the current VISA"""
 		if hasattr(self._rm, 'VisaManufacturerName'):
 			return self._rm.VisaManufacturerName
 		try:
-			return self._rm.visalib.get_attribute(self._rm.session, visa.constants.VI_ATTR_RSRC_MANF_NAME)[0]
+			return self._rm.visalib.get_attribute(self._rm.session, pyvisa.constants.VI_ATTR_RSRC_MANF_NAME)[0]
 		except TypeError:
 			return self._rm.visalib.__class__.__name__
 
@@ -288,8 +299,8 @@ class VisaSession(object):
 		Returns the last read Status Byte value."""
 		timeout_secs = timeout / 1000
 		self.clear_before_read()
-		if command.endswith('\n'):
-			command = command.rstrip('\n')
+		if command.endswith(self._term_char):
+			command = command.rstrip(self._term_char)
 		self.write(command + ';*OPC')
 		# Use catch to return the VISA Timeout back
 		start = time.time()
@@ -309,8 +320,8 @@ class VisaSession(object):
 			Returns the last read Status Byte value."""
 		timeout_secs = timeout / 1000
 		self.clear_before_read()
-		if command.endswith('\n'):
-			command = command.rstrip('\n')
+		if command.endswith(self._term_char):
+			command = command.rstrip(self._term_char)
 		self.write(command + ';*OPC')
 		start = time.time()
 		# STB polling loop
@@ -541,8 +552,8 @@ class VisaSession(object):
 		Timeout value 0 means the OPC timeout is used."""
 		timeout = self._resolve_opc_timeout(timeout)
 
-		if command.endswith('\n'):
-			command = command.rstrip('\n')
+		if command.endswith(self._term_char):
+			command = command.rstrip(self._term_char)
 		if is_query:
 			InstrumentErrors.assert_query_has_qmark(command, "Query with OPC")
 		else:
@@ -586,11 +597,11 @@ class VisaSession(object):
 		"""Writes command to the instrument."""
 		if self.write_delay > 0:
 			time.sleep(self.write_delay / 1000)
-		add_lf = False
-		if self._assure_write_with_lf and not cmd.endswith('\n'):
-			add_lf = True
-		if add_lf:
-			self._session.write(cmd + '\n')
+		add_tc = False
+		if self._assure_write_with_tc and not cmd.endswith(self._term_char):
+			add_tc = True
+		if add_tc:
+			self._session.write(cmd + self._term_char)
 		else:
 			self._session.write(cmd)
 
@@ -605,7 +616,7 @@ class VisaSession(object):
 		:param allow_chunk_events: [bool] if True, the method can send the chunk_events. If False, sending events is blocked.
 		:param prepend_data: Optional[bytes or string] You can prepend this data to the beginning. It will be considered part of the first chunk read
 		:return: read data [bytes or string], depending on the parameter binary."""
-		with self._session.ignore_warning(visa.constants.StatusCode.success_max_count_read):
+		with self._session.ignore_warning(pyvisa.constants.StatusCode.success_max_count_read):
 			if prepend_data and isinstance(prepend_data, str):
 				prepend_data = prepend_data.encode('utf-8')
 			chunk_ix = 0
@@ -630,7 +641,7 @@ class VisaSession(object):
 				if not stream.binary:
 					chunk = chunk.decode('utf-8')
 					if eot:
-						chunk = chunk.rstrip('\n')
+						chunk = chunk.rstrip(self._term_char)
 				stream.write(chunk)
 				if self.on_read_chunk_handler and allow_chunk_events:
 					total_size = len(stream) if eot is True else None
@@ -640,7 +651,7 @@ class VisaSession(object):
 
 	def _last_status_more_data_available(self):
 		"""Returns True, if the last status signalled that more data is available"""
-		return self.last_status == visa.constants.StatusCode.success_max_count_read
+		return self.last_status == pyvisa.constants.StatusCode.success_max_count_read
 
 	def _read_str_no_events(self) -> str:
 		"""Reads response from the instrument. The response is then trimmed for trailing LF. \n
@@ -659,8 +670,8 @@ class VisaSession(object):
 		self.write(query)
 		try:
 			response = self._read_str_no_events()
-		except visa.VisaIOError:
-			self._narrow_down_io_tout_error("Querying '{}' - ".format(query.rstrip('\n')))
+		except pyvisa.VisaIOError:
+			self._narrow_down_io_tout_error("Querying '{}' - ".format(query.rstrip(self._term_char)))
 		return response
 
 	def _read_str_timed(self, timeout: int, suppress_read_tout: bool = False) -> str:
@@ -702,8 +713,8 @@ class VisaSession(object):
 		self.write(query)
 		try:
 			response = self._read_str()
-		except visa.VisaIOError:
-			self._narrow_down_io_tout_error("Querying '{}' - ".format(query.rstrip('\n')))
+		except pyvisa.VisaIOError:
+			self._narrow_down_io_tout_error("Querying '{}' - ".format(query.rstrip(self._term_char)))
 		return response
 
 	def query_str_no_tout_err(self, query: str, tout: int) -> str:
@@ -714,7 +725,7 @@ class VisaSession(object):
 		try:
 			self.visa_timeout = tout
 			response = self.query_str(query)
-		except (visa.VisaIOError, InstrumentErrors.StatusException):
+		except (pyvisa.VisaIOError, InstrumentErrors.StatusException):
 			pass
 		finally:
 			self.visa_timeout = old_tout
@@ -775,7 +786,7 @@ class VisaSession(object):
 		if stb & StatusByte.message_available:
 			return
 		# Message not available
-		context = context + " SCPI query '{}'".format(query.rstrip('\n'))
+		context = context + " SCPI query '{}'".format(query.rstrip(self._term_char))
 		if stb & StatusByte.error_queue_not_empty:
 			# Instrument reports an error
 			InstrumentErrors.assert_no_instrument_status_errors(self._resource_name, self.query_all_syst_errors(), context)
@@ -803,7 +814,7 @@ class VisaSession(object):
 		:param data_stream: [StreamReader] data provider for the payload"""
 		data_size = len(data_stream)
 		len_str = f'{data_size}'
-		cmd = cmd.rstrip('\n')
+		cmd = cmd.rstrip(self._term_char)
 		if '#' in cmd:
 			raise Exception(
 				f"Command '{cmd}' must be provided without the binary data header. "
@@ -820,7 +831,7 @@ class VisaSession(object):
 			full_chunk = data_stream.read_as_binary()
 			write_buf = cmd_plus_header + full_chunk
 			if self._add_term_char_to_write_bin_block:
-				write_buf += b'\n'
+				write_buf += self._term_char_bin
 			self._session.write_raw(write_buf)
 			# Event sending
 			if self.on_write_chunk_handler:
@@ -855,7 +866,7 @@ class VisaSession(object):
 							# Append LF
 							self._session.write_raw(chunk)
 							self._session.send_end = True
-							self._session.write_raw(b'\n')
+							self._session.write_raw(self._term_char_bin)
 						else:
 							self._session.send_end = True
 							self._session.write_raw(chunk)
@@ -901,7 +912,7 @@ class VisaSession(object):
 			return data_type, whole_hdr, length
 
 		data_type = ReadDataType.ascii
-		if char == b'\n':
+		if char == self._term_char_bin:
 			data_type = ReadDataType.null
 		if self.vxi_capable:
 			# For Vxi session, to be sure, check whether there are more chars in the read buffer
@@ -911,10 +922,10 @@ class VisaSession(object):
 		whole_hdr = char.decode("utf-8")
 		if exc_if_not_bin:
 			if data_type == ReadDataType.null:
-				InstrumentErrors.throw_bin_block_unexp_resp_exception(self._resource_name, '\n')
+				InstrumentErrors.throw_bin_block_unexp_resp_exception(self._resource_name, self._term_char)
 			# Read 20 more characters to compose a better exception message
-			whole_hdr += self.read_up_to_char(b'\n', 20).decode("utf-8")
-			if self.last_status == visa.constants.StatusCode.success_max_count_read:
+			whole_hdr += self.read_up_to_char(self._term_char_bin, 20).decode("utf-8")
+			if self.last_status == pyvisa.constants.StatusCode.success_max_count_read:
 				self._flush_junk_data()
 			InstrumentErrors.throw_bin_block_unexp_resp_exception(self._resource_name, whole_hdr)
 		return data_type, whole_hdr, length
@@ -950,8 +961,8 @@ class VisaSession(object):
 				self._session.read_termination = False
 			# Binary data of known length
 			left_to_read = length
-			self.last_status = visa.constants.StatusCode.success
-			with self._session.ignore_warning(visa.constants.StatusCode.success_max_count_read):
+			self.last_status = pyvisa.constants.StatusCode.success
+			with self._session.ignore_warning(pyvisa.constants.StatusCode.success_max_count_read):
 				chunk_ix = 0
 				total_chunks = calculate_chunks_count(length, self._data_chunk_size)
 				while len(stream) < length:
@@ -965,12 +976,12 @@ class VisaSession(object):
 					chunk_ix += 1
 			if self._last_status_more_data_available():
 				if not self.vxi_capable:
-					self._session.read_termination = '\n'
+					self._session.read_termination = self._term_char
 				self._flush_junk_data()
 		finally:
 			# Make sure that in any case the self._session.read_termination is ON again for non-Vxi sessions
 			if not self.vxi_capable:
-				self._session.read_termination = '\n'
+				self._session.read_termination = self._term_char
 
 	def query_bin_block(self, query: str, stream: StreamWriter, exc_if_not_bin: bool = True) -> None:
 		"""Query binary data block and returns it as byte data. \n
@@ -1020,7 +1031,7 @@ class VisaSession(object):
 			response += char
 			if char in stop_chars:
 				break
-			if self.last_status != visa.constants.StatusCode.success_max_count_read:
+			if self.last_status != pyvisa.constants.StatusCode.success_max_count_read:
 				break
 		return response
 
