@@ -8,23 +8,23 @@ from .Internal.VisaSession import VisaSession
 
 
 class RsInstrument:
-	_driver_version_const = '1.4.0.29'
-	_driver_options_const = "SupportedInstrModels = All Rohde & Schwarz Instruments, SupportedIdnPatterns = Rohde(-|&)Schwarz, SimulationIdnString = Rohde&Schwarz*SimulationDevice*100001*" + _driver_version_const
+	_driver_version_const = '1.8.1.41'
+	_driver_options_const = "SupportedInstrModels = All Rohde & Schwarz Instruments, SupportedIdnPatterns = Rohde(-|&)Schwarz/Hameg, SimulationIdnString = Rohde&Schwarz*SimulationDevice*100001*" + _driver_version_const
 
 	def __init__(
 			self, resource_name: str, id_query: bool = True, reset: bool = False, options: str = None, direct_session: object = None):
 		"""Initializes new RsInstrument session. \n
-		For cleaner code, use the RsInstrument.from_existing_session(existing_session_obj)
 		Parameter options tokens examples:
-			- 'Simulate = True' - starts the session in simulation mode. Default: False
-			- 'SelectVisa = 'pyvisa' - uses python implementation of VISA, where you do not need the VISA-C installation
-			- 'SelectVisa = 'rs' - forces usage of Rohde&Schwarz Visa
-			- 'SelectVisa = 'ni' - forces usage of National Instruments Visa
+			- 'Simulate=True' - starts the session in simulation mode. Default: False
+			- 'SelectVisa=socket' - uses no VISA implementation for socket connections - you do not need any VISA-C installation
+			- 'SelectVisa=rs' - forces usage of RohdeSchwarz Visa
+			- 'SelectVisa=ni' - forces usage of National Instruments Visa
 			- 'QueryInstrumentStatus = False' - same as driver.utilities.instrument_status_checking = False. Default: True.
 			- 'DriverSetup=(WriteDelay = 20, ReadDelay = 5)' - Introduces delay of 20ms before each write and 5ms before each read. Default: 0ms for both
 			- 'DriverSetup=(OpcWaitMode = OpcQuery)' - mode for all the opc-synchronised write/reads. Other modes: StbPolling, StbPollingSlow, StbPollingSuperSlow. Default: StbPolling
 			- 'DriverSetup=(AddTermCharToWriteBinBLock = True)' - Adds one additional LF to the end of the binary data (some instruments require that). Default: False
-			- 'DriverSetup=(AssureWriteWithLf = True)' - Makes sure each command/query is terminated with linefeed character. Default: Interface dependent
+			- 'DriverSetup=(AssureWriteWithTermChar = True)' - Makes sure each command/query is terminated with termination character. Default: Interface dependent
+			- 'DriverSetup=(TerminationCharacter = '\n')' - Sets the termination character for reading. Default: '\n' (LineFeed)
 			- 'DriverSetup=(IoSegmentSize = 10E3)' - Maximum size of one write/read segment. If transferred data is bigger, it is split to more segments. Default: 1E6 bytes
 			- 'DriverSetup=(OpcTimeout = 10000)' - same as driver.utilities.opc_timeout = 10000. Default: 30000ms
 			- 'DriverSetup=(VisaTimeout = 5000)' - same as driver.utilities.visa_timeout = 5000. Default: 10000ms
@@ -61,11 +61,11 @@ class RsInstrument:
 	@staticmethod
 	def list_resources(expression: str = '?*::INSTR', visa_select: str = None) -> List[str]:
 		"""Finds all the resources defined by the expression
-		:param: expression examples:
 			- '?*' - matches all the available instruments
 			- 'USB::?*' - matches all the USB instruments
 			- "TCPIP::192?*' - matches all the LAN instruments with the IP address starting with 192
-		:param: visa_select - optional parameter selecting a specific VISA. Examples: '@ni', '@rs'
+		:param expression: see the examples in the function
+		:param visa_select: optional parameter selecting a specific VISA. Examples: '@ni', '@rs'
 		"""
 		rm = VisaSession.get_resource_manager(visa_select)
 		resources = rm.list_resources(expression)
@@ -407,3 +407,20 @@ class RsInstrument:
 	def get_last_sent_cmd(self) -> str:
 		"""Returns the last commands sent to the instrument. Only works in simulation mode"""
 		return self._core.get_last_sent_cmd()
+
+	@staticmethod
+	def assert_minimum_version(min_version: str) -> None:
+		"""Asserts that the driver version fulfills the minimum required version you have entered.
+		This way you make sure your installed driver is of the entered version or newer."""
+		min_version_list = min_version.split('.')
+		curr_version_list = RsInstrument._driver_version_const.split('.')
+		count_min = len(min_version_list)
+		count_curr = len(curr_version_list)
+		count = count_min if count_min < count_curr else count_curr
+		for i in range(count):
+			minimum = int(min_version_list[i])
+			curr = int(curr_version_list[i])
+			if curr > minimum:
+				break
+			if curr < minimum:
+				raise Exception(f"Assertion for minimum RsInstrument version failed. Current version: '{RsInstrument._driver_version_const}', minimum required version: '{min_version}'")
